<?php

namespace Litecms\Article\Forms;

use Litepie\Form\FormInterpreter;

class Article extends FormInterpreter
{

    /**
     * Sets the form and form elements.
     * @return null.
     */
    public static function setAttributes()
    {

        self::$urls = [
            'new' => [
                'url' => guard_url('article/article/new'),
                'method' => 'GET',
            ],
            'create' => [
                'url' => guard_url('article/article/create'),
                'method' => 'GET',
            ],
            'store' => [
                'url' => guard_url('article/article'),
                'method' => 'POST',
            ],
            'update' => [
                'url' => guard_url('article/article'),
                'method' => 'PUT',
            ],
            'list' => [
                'url' => guard_url('article/article'),
                'method' => 'GET',
            ],
            'delete' => [
                'url' => guard_url('article/article'),
                'method' => 'DELETE',
            ],
        ];
        self::$search = [
            'name' => [
                "type" => 'text',
                "label" => trans('article::article.label.name'),
                "placeholder" => trans('article::article.placeholder.name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "4",
                "roles" => [],
            ]
        ];
        self::$orderBy = [
            'created_at' => trans('article::article.label.created_at'),
            'name' => trans('article::article.label.name'),
            'status' => trans('article::article.label.status'),
        ];
        self::$groups = [
            'main' => trans('article::article.groups.main'),
            'details' => trans('article::article.groups.details'),
            'images' => trans('article::article.groups.images'),
            'settings' => trans('article::article.groups.settings'),
        ];
        self::$list = [
            [
                'key' => "ref",
                'label' => trans('article::article.label.ref'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "id",
                'label' => trans('article::article.label.id'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "name",
                'label' => trans('article::article.label.name'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "status",
                'label' => trans('article::article.label.status'),
                'sortable' => 'true',
                'roles' => [],
            ],
        ];
        self::$fields = [
                'title' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('article::article.label.title'),
                "placeholder" => trans('article::article.placeholder.title'),
                "required" => 'true',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'slug' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('article::article.label.slug'),
                "placeholder" => trans('article::article.placeholder.slug'),
                "required" => 'true',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'url' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('article::article.label.url'),
                "placeholder" => trans('article::article.placeholder.url'),
                "required" => 'true',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'blurb' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('article::article.label.blurb'),
                "placeholder" => trans('article::article.placeholder.blurb'),
                "required" => 'true',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'banner' => [
                "element" => 'file',
                "type" => 'image',
                "label" => trans('article::article.label.banner'),
                "placeholder" => trans('article::article.placeholder.banner'),
                "required" => 'true',
                "group" => "main",
                "section" => "first",
                "col" => "12",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'status' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('article::article.label.status'),
                "placeholder" => trans('article::article.placeholder.status'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'published_at' => [
                "element" => 'datetime',
                "type" => 'datetime',
                "label" => trans('article::article.label.published_at'),
                "placeholder" => trans('article::article.placeholder.published_at'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'editor' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('article::article.label.editor'),
                "placeholder" => trans('article::article.placeholder.editor'),
                "required" => 'true',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
        ];

        return new static();
    }
}
