<?php

namespace Litecms\Article\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Article\Models\Article;

class ArticlePolicy
{

    /**
     * Determine if the given user can view the article.
     *
     * @param UserPolicyInterface $authUser
     * @param Article $article
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Article $article)
    {
        if ($authUser->canDo('article.article.view') && $authUser->isAdmin()) {
            return true;
        }

        return $article->user_id == user_id() && $article->user_type == user_type();
    }

    /**
     * Determine if the given user can create a article.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('article.article.create');
    }

    /**
     * Determine if the given user can update the given article.
     *
     * @param UserPolicyInterface $authUser
     * @param Article $article
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Article $article)
    {
        if ($authUser->canDo('article.article.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $article->user_id == user_id() && $article->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given article.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Article $article)
    {
        return $article->user_id == user_id() && $article->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given article.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Article $article)
    {
        if ($authUser->canDo('article.article.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given article.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Article $article)
    {
        if ($authUser->canDo('article.article.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
